Documentation
¶
Overview ¶
Package cmd implements the command-line interface of k6.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExecuteWithGlobalState ¶
func ExecuteWithGlobalState(gs *state.GlobalState)
ExecuteWithGlobalState runs the root command with an existing GlobalState. It adds all child commands to the root command and it sets flags appropriately. It is called by main.main(). It only needs to happen once to the rootCmd.
Types ¶
type Config ¶
type Config struct {
lib.Options
Out []string `json:"out" envconfig:"K6_OUT"`
Linger null.Bool `json:"linger" envconfig:"K6_LINGER"`
NoUsageReport null.Bool `json:"noUsageReport" envconfig:"K6_NO_USAGE_REPORT"`
WebDashboard null.Bool `json:"webDashboard" envconfig:"K6_WEB_DASHBOARD"`
// NoArchiveUpload is an option that is only used when running in local-execution mode with the cloud run
// command.
//
// Because the implementation of k6 cloud run calls the same code as the k6 run command under the hood, we
// need to be able to pass down a configuration option that is only relevant to the cloud run command.
NoArchiveUpload null.Bool `json:"noArchiveUpload" envconfig:"K6_NO_ARCHIVE_UPLOAD"`
// TODO: deprecate
Collectors map[string]json.RawMessage `json:"collectors"`
}
Config ...
type RawFormatter ¶
type RawFormatter struct{}
RawFormatter it does nothing with the message just prints it
Source Files
¶
- archive.go
- builtin_output_gen.go
- cloud.go
- cloud_login.go
- cloud_run.go
- cloud_upload.go
- common.go
- config.go
- deps.go
- doc.go
- inspect.go
- launcher.go
- login.go
- login_cloud.go
- login_influxdb.go
- new.go
- options.go
- outputs.go
- outputs_cloud.go
- pause.go
- report.go
- resume.go
- root.go
- run.go
- runtime_options.go
- scale.go
- stats.go
- status.go
- subcommand.go
- test_load.go
- ui.go
- ui_unix.go
- version.go
Directories
¶
| Path | Synopsis |
|---|---|
|
Package templates provides the templates used by the `k6 new` command
|
Package templates provides the templates used by the `k6 new` command |
|
Package tests contains integration tests that run k6 commands, and interact with standard I/O streams.
|
Package tests contains integration tests that run k6 commands, and interact with standard I/O streams. |
|
events
Package events is used for testing the event functionality.
|
Package events is used for testing the event functionality. |
Click to show internal directories.
Click to hide internal directories.